StorageInfoPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • StorageInfoPlatform
Implementers

Constructors

StorageInfoPlatform()
Constructs a StorageInfoPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getExternalStorageFreeSpace() → Future<int>
getExternalStorageTotalSpace() → Future<int>
getExternalStorageUsedSpace() → Future<int>
getStorageFreeSpace() → Future<int>
getStorageTotalSpace() → Future<int>
getStorageUsedSpace() → Future<int>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ StorageInfoPlatform
The default instance of StorageInfoPlatform to use.
getter/setter pair